#!/bin/sh 
#********************************************************************************
# (c) Copyright [2019-2020] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty 
# statements accompanying such products and services. Nothing herein should be 
# construed as constituting an additional warranty. Micro Focus shall not be liable
# for technical or editorial errors or omissions contained herein. The information 
# contained herein is subject to change without notice.
#********************************************************************************

OLD_DB_PATH="/var/opt/novell/iprintmobile/databases"
DB_PATH="/var/opt/novell/orientdb/databases"
ORIENTDB_CONFIG_FILE="/usr/share/orientdb/bin/serverconfigured"
DB_BACKUP_TAR_FILE="/tmp/db_backup.tar"
CREDSTORE_CONF="/etc/opt/novell/iprintmobile/conf/credstore.conf"
ERR_LOG="/var/opt/novell/log/iprintmobile/config_db.log"
VOL=""

isCluster() 
{
    IPRINT_NSS=$(grep Required-Start /opt/novell/iprint/init.d/novell-ipsmd | grep nss)
    if [ ! -z "${IPRINT_NSS}" ]; then
        echo "Cluster setup" >> ${ERR_LOG}
        return 1
    else
        echo "Not a cluster setup" >> ${ERR_LOG}
        return 0
    fi
}

isPoolRunningOnThisNode()
{
    MEDIA_DIR=$(readlink /etc/opt/novell/iprint/conf)
    TEST_FILE="$MEDIA_DIR/iprintconf.properties"
    if [ -f $TEST_FILE ]; then
        echo "Pool is running on this node" >> ${ERR_LOG}
        return 1
    else
        echo "Pool is not running on this node" >> ${ERR_LOG}
        return 0
    fi
}

getVolumePath()
{
    VOL=$(readlink /etc/opt/novell/iprint/conf | awk -F/ '{print $(NF-5)}')
    echo "/media/nss/$VOL"
}

configDB()
{
	echo "Configuring Database" | tee -a ${ERR_LOG}	
	if [ -d ${OLD_DB_PATH} ]; then
		migrateDB
		if [ $? -ne 0 ]; then
			echo "Error database migration, exiting..." | tee -a ${ERR_LOG}
			exit -1
		fi
	fi
	
	if [ ! -f $CREDSTORE_CONF ]; then
		touch $CREDSTORE_CONF > /dev/null 2>&1
	fi
	
	if [ ! -f $ORIENTDB_CONFIG_FILE ]; then
		echo "Configuring Orientdb server" | tee -a ${ERR_LOG}
		base64 -di $CREDSTORE_CONF | grep orientdb.password > /dev/null 2>&1
		if [ $? -ne 0 ]; then
			echo "Configuring cred store"
			mv $CREDSTORE_CONF $CREDSTORE_CONF.bkp | tee -a ${ERR_LOG}
			sh /opt/novell/iprintmobile/bin/db_util.sh --config | tee -a ${ERR_LOG}
		fi
	fi
	
	echo "Setting Permissions" | tee -a ${ERR_LOG}
	chown iprintmobile:iprint /usr/share/orientdb/config/orientdb-server-config.xml
	chmod 644 /usr/share/orientdb/config/orientdb-server-config.xml
	
	systemctl daemon-reload
	systemctl start orientdb.service | tee -a ${ERR_LOG}
	systemctl status orientdb.service | tee -a ${ERR_LOG}
}

migrateDB()
{	
	echo "Old database path detected. Migrating to new database path..." | tee -a ${ERR_LOG}	
	if [ ! -d ${DB_PATH}/iprint ];then
		echo "Creating old database backup file : " ${DB_BACKUP_TAR_FILE} | tee -a ${ERR_LOG}
		tar -cvf ${DB_BACKUP_TAR_FILE} ${OLD_DB_PATH} | tee -a ${ERR_LOG}
		
		echo "Copying old database path..." | tee -a ${ERR_LOG}
		cp -r ${OLD_DB_PATH}/iprint ${DB_PATH} > /dev/null 2>&1
		if [ $? -ne 0 ]; then
			echo "Error copying database." | tee -a ${ERR_LOG}
			return -1
		fi
	fi
	#Deleting old db path directory
	echo "Deleting old database path..." | tee -a ${ERR_LOG}
	rm -rf ${OLD_DB_PATH}/iprint | tee -a ${ERR_LOG}
	rm -rf ${OLD_DB_PATH} | tee -a ${ERR_LOG}
	if [ $? -ne 0 ]; then
		echo "Could not remove old database." | tee -a ${ERR_LOG}
	fi
	#Set Permission for the db directory
	echo "Setting Permissions for the database path..." | tee -a ${ERR_LOG}
	chown -R iprintmobile:iprint ${DB_PATH}
	chmod 755 ${DB_PATH}
	chmod 755 ${DB_PATH}/iprint
}

isCluster
if [[ $? -eq 1 ]]; then
    isPoolRunningOnThisNode
    if [[ $? -eq 1 ]]; then
        echo "Pool is running on this node" >> ${ERR_LOG}
		configDB
		systemctl enable orientdb | tee -a ${ERR_LOG}
	fi
else
	echo "Stand alone server " >> ${ERR_LOG}
	configDB
	systemctl enable orientdb | tee -a ${ERR_LOG}
fi
